@@ -343,8 +343,9 @@ class ReposConf(object):
             config.read(conffile, encoding="utf-8")
             for rep in config.sections():
                 if rep not in skip_reps:
-                    location = config[rep]["location"]
-                    if location:
+                    location = config[rep].get("location")
+                    synctype = config[rep].get("sync-type")
+                    if location and synctype:
                         yield rep, location
 
 
